
## Markdown Licenses

A collection of open source licenses in [Markdown format](http://daringfireball.net/projects/markdown/).

Pull requests with new licenses are always welcome!

### Why Markdown?

Because it's pretty! But most importantly, it's easier to read; after all, licenses are read by humans, not computers.

Compare these two files:
 - [GNU GPL v3 - Original plaintext version](http://www.gnu.org/licenses/gpl-3.0.txt)
 - [GNU GPL v3 - Markdown formatted version](gnu-gpl-v3.0.md)

### Isn't editing the license a violation of the license?

Some licenses have lines like this one found in _GNU GPL v3_:

> Everyone is permitted to copy and distribute verbatim copies of this license document, **but changing it is not allowed**.

I'm no legal expert, however, considering that GNU provides [a list of their licenses in various formats](http://www.gnu.org/licenses/#GPL), I would assume that so long as the original **wording** remains intact, modification to the formatting (within reason) is allowed.

### In the event of a fire

If there is any inconsistency between the markdown formatted license and the license it represents,
please refer to the original license (found in [CREDITS.md](CREDITS.md)) for the _correct_ wording.

Please read the licenses ahead of time to make sure they are correct, and use them at your own risk. Although we have strived to keep the license wording identical to the originals, we are not responsible for any legal implications caused by discrepancies in the licenses.

